@@ -7,7 +7,7 @@ Attean::API - Utility package for loading all Attean role packages.
 
 =head1 VERSION
 
-This document describes Attean::API version 0.002_02
+This document describes Attean::API version 0.003_01
 
 =head1 SYNOPSIS
 
@@ -21,15 +21,15 @@ in the Attean::API namespace.
 
 =cut
 
-package Attean::API::ResultOrTerm 0.001 {
+package Attean::API::ResultOrTerm 0.003 {
 	use Moo::Role;
 }
 
-package Attean::API::BlankOrIRI 0.001 {
+package Attean::API::BlankOrIRI 0.003 {
 	use Moo::Role;
 }
 
-package Attean::API::TermOrVariable 0.001 {
+package Attean::API::TermOrVariable 0.003 {
 	use Moo::Role;
 	sub equals {
 		my ($a, $b)	= @_;
@@ -37,21 +37,26 @@ package Attean::API::TermOrVariable 0.001 {
 	}
 }
 
-package Attean::Mapper 0.001 {
+package Attean::Mapper 0.003 {
 	use Moo::Role;
 	requires 'map'; # my $that = $object->map($this)
 }
 
-package Attean::API::Variable 0.001 {
+package Attean::API::Variable 0.003 {
 	use Moo::Role;
 	with 'Attean::API::TermOrVariable';
+	sub as_sparql {
+		my $self	= shift;
+		return '?' . $self->value;
+	}
+	
 	sub as_string {
 		my $self	= shift;
 		return '?' . $self->value;
 	}
 }
 
-package Attean::API::CanonicalizingBindingSet 0.001 {
+package Attean::API::CanonicalizingBindingSet 0.003 {
 	use Moo::Role;
 	use Attean::RDF;
 	use namespace::clean;
@@ -142,7 +147,7 @@ package Attean::API::CanonicalizingBindingSet 0.001 {
 	}
 }
 
-package Attean::API 0.001 {
+package Attean::API 0.003 {
 	use Attean::API::Term;
 	use Attean::API::Store;
 	use Attean::API::Model;
@@ -151,7 +156,8 @@ package Attean::API 0.001 {
 	use Attean::API::Serializer;
 	use Attean::API::Query;
 	use Attean::API::Expression;
-
+	use Attean::API::Plan;
+	
 	use Attean::Variable;
 	use Attean::Blank;
 	use Attean::IRI;
