@@ -7,7 +7,7 @@ Attean::API::Expression - SPARQL expressions
 
 =head1 VERSION
 
-This document describes Attean::API::Expression version 0.002_02
+This document describes Attean::API::Expression version 0.003_01
 
 =head1 DESCRIPTION
 
@@ -65,15 +65,16 @@ Returns a string serialization of the expression object.
 
 =cut
 
-package Attean::API::Expression 0.001 {
+package Attean::API::Expression 0.003 {
 	use Moo::Role;
 	use Types::Standard qw(Str);
 	use namespace::clean;
 
-	with 'Attean::API::DirectedAcyclicGraph';
+	with 'Attean::API::DirectedAcyclicGraph', 'Attean::API::UnionScopeVariables';
 	
 	has 'operator' => (is => 'ro', isa => Str, required => 1);
 	requires 'as_string';
+	requires 'as_sparql';
 	
 	sub BUILD {}
 	if ($ENV{ATTEAN_TYPECHECK}) {
@@ -97,7 +98,7 @@ package Attean::API::Expression 0.001 {
 	}
 }
 
-package Attean::API::UnaryExpression 0.001 {
+package Attean::API::UnaryExpression 0.003 {
 	use Moo::Role;
 	with 'Attean::API::Expression', 'Attean::API::UnaryQueryTree';
 	sub as_string {
@@ -105,9 +106,13 @@ package Attean::API::UnaryExpression 0.001 {
 		my ($data)	= @{ $self->children };
 		return sprintf("%s(%s)", $self->operator, $data->as_string);
 	}
+	sub as_sparql {
+		my $self	= shift;
+		return $self->as_string;
+	}
 }
 
-package Attean::API::BinaryExpression 0.001 {
+package Attean::API::BinaryExpression 0.003 {
 	use Moo::Role;
 	with 'Attean::API::Expression', 'Attean::API::BinaryQueryTree';
 	sub as_string {
@@ -115,9 +120,13 @@ package Attean::API::BinaryExpression 0.001 {
 		my ($lhs, $rhs)	= @{ $self->children };
 		return sprintf("(%s %s %s)", $lhs->as_string, $self->operator, $rhs->as_string);
 	}
+	sub as_sparql {
+		my $self	= shift;
+		return $self->as_string;
+	}
 }
 
-package Attean::API::NaryExpression 0.001 {
+package Attean::API::NaryExpression 0.003 {
 	use Moo::Role;
 	with 'Attean::API::Expression', 'Attean::API::QueryTree';
 	sub as_string {
@@ -125,9 +134,13 @@ package Attean::API::NaryExpression 0.001 {
 		my @children	= map { $_->as_string } @{ $self->children };
 		return sprintf("%s(%s)", $self->operator, join(', ', @children));
 	}
+	sub as_sparql {
+		my $self	= shift;
+		return $self->as_string;
+	}
 }
 
-package Attean::API::AggregateExpression 0.001 {
+package Attean::API::AggregateExpression 0.003 {
 	use Moo::Role;
 	requires 'operator';
 	requires 'scalar_vars';
