@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.002_02
+This document describes Attean::API::Iterator version 0.003_01
 
 =head1 DESCRIPTION
 
@@ -96,7 +96,7 @@ elements from the referent.
 
 =cut
 
-package Attean::API::Iterator 0.001 {
+package Attean::API::Iterator 0.003 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
@@ -123,7 +123,8 @@ package Attean::API::Iterator 0.001 {
 	around 'BUILD' => sub {
 		my $orig	= shift;
 		my $self	= shift;
-		$self->$orig(@_);
+		my $args	= shift;
+		$self->$orig($args);
 		my $role	= $self->item_type;
 		if (Role::Tiny->is_role($role)) {
 			my $check	= sub {
@@ -138,10 +139,12 @@ package Attean::API::Iterator 0.001 {
 				Role::Tiny->apply_roles_to_object($self, 'Attean::API::MixedStatementIterator');
 			} elsif ($check->('Attean::API::Result')) {
 				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultIterator');
+				$self->variables($args->{variables} || []);
 			} elsif ($check->('Attean::API::Term')) {
 				Role::Tiny->apply_roles_to_object($self, 'Attean::API::TermIterator');
 			} elsif ($check->('Attean::API::ResultOrTerm')) {
 				Role::Tiny->apply_roles_to_object($self, 'Attean::API::ResultOrTermIterator');
+				$self->variables($args->{variables} || []);
 			}
 
 			if ($self->does('Attean::API::RepeatableIterator') and $check->('Attean::API::Binding')) {
@@ -198,7 +201,13 @@ package Attean::API::Iterator 0.001 {
 			}
 		}
 		
-		return Attean::CodeIterator->new( item_type => $type, generator => $generator );
+		# copy variables into new iterator if $self does ::ResultIterator or ::ResultOrTermIterator
+		my %args;
+		if ($self->can('variables')) {
+			$args{variables}	= $self->variables;
+		}
+		
+		return Attean::CodeIterator->new( %args, item_type => $type, generator => $generator );
 	}
 
 	sub grep {
@@ -254,7 +263,7 @@ package Attean::API::Iterator 0.001 {
 	}
 }
 
-package Attean::API::RepeatableIterator 0.001 {
+package Attean::API::RepeatableIterator 0.003 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -290,8 +299,10 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.001 {
+package Attean::API::ResultOrTermIterator 0.003 {
 	use Moo::Role;
+	use Types::Standard qw(ArrayRef Str);
+	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
 	sub canonicalize {
 		my $self	= shift;
 		my $mapper	= Attean::TermMap->canonicalization_map;
@@ -307,7 +318,7 @@ package Attean::API::ResultOrTermIterator 0.001 {
 	}
 }
 
-package Attean::API::TripleIterator 0.001 {
+package Attean::API::TripleIterator 0.003 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	sub as_quads {
@@ -317,12 +328,12 @@ package Attean::API::TripleIterator 0.001 {
 	}
 }
 
-package Attean::API::QuadIterator 0.001 {
+package Attean::API::QuadIterator 0.003 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 }
 
-package Attean::API::MixedStatementIterator 0.001 {
+package Attean::API::MixedStatementIterator 0.003 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	sub as_quads {
@@ -335,9 +346,11 @@ package Attean::API::MixedStatementIterator 0.001 {
 	}
 }
 
-package Attean::API::ResultIterator 0.001 {
+package Attean::API::ResultIterator 0.003 {
 	use Moo::Role;
+	use Types::Standard qw(Str ArrayRef);
 	with 'Attean::API::CanonicalizingBindingIterator';
+	has 'variables' => (is => 'rw', isa => ArrayRef[Str], required => 1);
 	sub join {
 		my $self	= shift;
 		my $rhs		= shift;
@@ -354,7 +367,7 @@ package Attean::API::ResultIterator 0.001 {
 	}
 }
 
-package Attean::API::TermIterator 0.001 {
+package Attean::API::TermIterator 0.003 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
