@@ -7,7 +7,7 @@ Attean::QuadModel - RDF model backed by a quad-store
 
 =head1 VERSION
 
-This document describes Attean::QuadModel version 0.002_02
+This document describes Attean::QuadModel version 0.003_01
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ quad-store.
 
 =cut
 
-package Attean::QuadModel 0.001 {
+package Attean::QuadModel 0.003 {
 	use Moo;
 	use Scalar::Util qw(reftype);
 	use namespace::clean;
@@ -90,11 +90,28 @@ L<Attean::API::QuadIterator>.
 		}
 	}
 	
+	sub plans_for_algebra {
+		my $self	= shift;
+		if ($self->store->does('Attean::API::CostPlanner')) {
+			return $self->store->plans_for_algebra(@_);
+		}
+		return;
+	}
+	
+	sub cost_for_plan {
+		my $self	= shift;
+		if ($self->store->does('Attean::API::CostPlanner')) {
+			return $self->store->cost_for_plan(@_);
+		}
+		return;
+	}
+	
 	with 'Attean::API::Model';
+	with 'Attean::API::CostPlanner';
 }
 
 
-package Attean::MutableQuadModel 0.001 {
+package Attean::MutableQuadModel 0.003 {
 	use Moo;
 	extends 'Attean::QuadModel';
 	
