@@ -7,7 +7,7 @@ Attean::Triple - RDF Triples
 
 =head1 VERSION
 
-This document describes Attean::Triple version 0.002_02
+This document describes Attean::Triple version 0.003_01
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ This role consumes L<Attean::API::Triple>.
 
 =cut
 
-package Attean::TriplePattern 0.001 {
+package Attean::TriplePattern 0.003 {
 	use Moo;
 	use Attean::API::Binding;
 	
@@ -58,9 +58,20 @@ package Attean::TriplePattern 0.001 {
 		}
 		return $class->$orig(@_);
 	};
+	
+	sub as_quadpattern {
+		my $self	= shift;
+		my $graph	= shift;
+		return Attean::QuadPattern->new(
+			subject		=> $self->subject,
+			predicate	=> $self->predicate,
+			object		=> $self->object,
+			graph		=> $graph,
+		);
+	}
 }
 
-package Attean::Triple 0.001 {
+package Attean::Triple 0.003 {
 	use Moo;
 	use Attean::API::Binding;
 	
