@@ -4,13 +4,13 @@ AtteanX::Serializer::CanonicalNTriples - Canonical N-Triples Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::CanonicalNTriples version 0.002_02
+This document describes AtteanX::Serializer::CanonicalNTriples version 0.003_01
 
 =head1 SYNOPSIS
 
  use Attean;
  my $serializer = Attean->get_serializer('NTriples')->new();
- $serializer->serialize_iter_to_io( $iter, $fh );
+ $serializer->serialize_iter_to_io( $io, $iter );
 
 =head1 DESCRIPTION
 
@@ -25,7 +25,7 @@ This document describes AtteanX::Serializer::CanonicalNTriples version 0.002_02
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::CanonicalNTriples 0.001 {
+package AtteanX::Serializer::CanonicalNTriples 0.003 {
 	use Moo;
 	use Encode;
 	extends 'AtteanX::Serializer::NTriples';
