@@ -4,13 +4,13 @@ AtteanX::Serializer::NTuples - Shared functionality for N-Triples and N-Quads se
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NTuples version 0.002_02
+This document describes AtteanX::Serializer::NTuples version 0.003_01
 
 =head1 SYNOPSIS
 
  use Attean;
- my $parser = Attean->get_serializer('NTriples')->new();
- $parser->serialize_iter_to_io( $fh );
+ my $serializer = Attean->get_serializer('NTriples')->new();
+ $serializer->serialize_iter_to_io( $io, $fh );
 
 =head1 DESCRIPTION
 
@@ -25,7 +25,7 @@ This document describes AtteanX::Serializer::NTuples version 0.002_02
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::NTuples 0.001 {
+package AtteanX::Serializer::NTuples 0.003 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::ListIterator;
